"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var Q = require('q');
var base_authorization_1 = require("./base.authorization");
var controller_utils_1 = require("./controller.utils");
var entity_utils_1 = require("./entity.utils");
var base_query_builder_1 = require("./base.query-builder");
function baseCtrlCreate(req, res, model, options) {
    entityFromBody(req, options.setUser)
        .then(base_authorization_1.checkAuthorization('create', req.body))
        .then(entity_utils_1.createEntity(model))
        .then(controller_utils_1.respondWithResult(res))
        .catch(controller_utils_1.handleError(res));
}
exports.baseCtrlCreate = baseCtrlCreate;
function baseCtrlFind(req, res, model) {
    base_query_builder_1.queryBuilder(model)
        .byUser(req.user)
        .exec()
        .then(controller_utils_1.respondWithResult(res))
        .catch(controller_utils_1.handleError(res));
}
exports.baseCtrlFind = baseCtrlFind;
function baseCtrlFindById(req, res, model) {
    entity_utils_1.findEntityById(model, req.params.id)
        .then(controller_utils_1.handleEntityNotFound(res))
        .then(base_authorization_1.checkAuthorization('read', req))
        .then(controller_utils_1.respondWithResult(res))
        .catch(controller_utils_1.handleError(res));
}
exports.baseCtrlFindById = baseCtrlFindById;
function baseCtrlUpdate(req, res, model) {
    //contruct query
    entity_utils_1.findEntityById(model, req.params.id)
        .then(controller_utils_1.handleEntityNotFound(res))
        .then(base_authorization_1.checkAuthorization('update', req))
        .then(entity_utils_1.applyUpdate(req.body))
        .then(controller_utils_1.respondWithResult(res))
        .catch(controller_utils_1.handleError(res));
}
exports.baseCtrlUpdate = baseCtrlUpdate;
function baseCtrlRemove(req, res, model) {
    //contruct query
    entity_utils_1.findEntityById(model, req.params.id)
        .then(base_authorization_1.checkAuthorization('delete', req))
        .then(entity_utils_1.removeEntity())
        .then(controller_utils_1.respondWithResult(res))
        .catch(controller_utils_1.handleError(res));
}
exports.baseCtrlRemove = baseCtrlRemove;
function entityFromBody(req, setUser) {
    var entity = req.body;
    if (req.user && setUser)
        entity.userId = req.user._id;
    return Q.when(entity);
}
